@@ -1592,7 +1592,6 @@ Pascal Outline mode provides some additional commands.
   (pascal-hide-other-defuns))
 
 ;; XEmacs addition
-;;;###autoload
-(add-to-list 'auto-mode-alist '("\\.p\\(?:as\\)?\\'" . pascal-mode))
+;;;###autoload(add-to-list 'auto-mode-alist '("\\.p\\(?:as\\)?\\'" . pascal-mode))
 
 ;;; pascal.el ends here
